@@ -29,7 +29,6 @@ __all__ = [
     'Credentials',
     ]
 
-import cgi
 try:
     from cStringIO import StringIO
 except ImportError:
@@ -60,6 +59,8 @@ try:
 except ImportError:
     import simplejson as json
 
+from six.moves.urllib.parse import parse_qs
+
 if bytes is str:
     # Python 2
     unicode_type = unicode
@@ -248,7 +249,7 @@ class AccessToken(_AccessToken):
         """Create and return a new `AccessToken` from the given string."""
         if not isinstance(query_string, unicode_type):
             query_string = query_string.decode('utf-8')
-        params = cgi.parse_qs(query_string, keep_blank_values=False)
+        params = parse_qs(query_string, keep_blank_values=False)
         key = params['oauth_token']
         assert len(key) == 1, (
             "Query string must have exactly one oauth_token.")
