@@ -529,12 +529,15 @@ class TestLaunchpadLoginWith(KeyringTest):
     def test_None_launchpadlib_dir(self):
         # If no launchpadlib_dir is passed in to login_with,
         # $HOME/.launchpadlib is used.
-        old_home = os.environ['HOME']
+        old_home = os.environ.get('HOME')
         os.environ['HOME'] = self.temp_dir
         launchpad = NoNetworkLaunchpad.login_with(
             'app name', service_root=SERVICE_ROOT)
         # Reset the environment to the old value.
-        os.environ['HOME'] = old_home
+        if old_home is not None:
+            os.environ['HOME'] = old_home
+        else:
+            del os.environ['HOME']
 
         cache_dir = launchpad.passed_in_args['cache']
         launchpadlib_dir = os.path.abspath(
@@ -579,6 +582,7 @@ class TestDeprecatedLoginMethods(KeyringTest):
         # login() works but triggers a deprecation warning.
         with warnings.catch_warnings(record=True) as caught:
             warnings.simplefilter("always")
+            warnings.simplefilter("ignore", PendingDeprecationWarning)
             NoNetworkLaunchpad.login('consumer', 'token', 'secret')
             self.assertEqual(len(caught), 1)
             self.assertEqual(caught[0].category, DeprecationWarning)
@@ -587,6 +591,7 @@ class TestDeprecatedLoginMethods(KeyringTest):
         # get_token_and_login() works but triggers a deprecation warning.
         with warnings.catch_warnings(record=True) as caught:
             warnings.simplefilter("always")
+            warnings.simplefilter("ignore", PendingDeprecationWarning)
             NoNetworkLaunchpad.get_token_and_login('consumer')
             self.assertEqual(len(caught), 1)
             self.assertEqual(caught[0].category, DeprecationWarning)
